@@ -16,6 +16,7 @@ debian/rules.defs
 debian/sync.sh
 debian/watch
 debian/source/lintian-overrides
+debian/tests/autopkgtest-pkg-dkms.conf
 debian/tests/control
 debian/upstream/metadata
 "
@@ -36,7 +37,7 @@ do
 	fi
 done
 
-for psrc in "$ngd/debian/patches/module"/*.patch
+for psrc in "$ngd/debian/patches/module"/*.patch "$ngd/debian/patches/module"/series*
 do
 	pdst=${psrc#$ngd/}
 	if ! cmp -s "$psrc" "$pdst" ; then
